---
tags:
  - prompt
author: agp
source:
- ^[0-2].*
- ^3[0-1].*
---

# Prompt

Consider documents located in the same directory as this file.

Organize all previous existing documents (from 001.xxx to 319.xxx) to generate a consistent specification document that group all aspects of the application creating a nested hierarchy of specifications that goes from higher level to smaller and fine level.

1. Write the result in a new file named `325.spec.results.md`.
2. User Markdown format with bulleted ticks (tasks) to organize the specifications.
3. Write an extra file `326.spec.considerations.md` with a detailed explanation of the specifications, including any assumptions, constraints, and dependencies.
